@@ -1,24 +1,23 @@
 # -*- coding: utf-8 -*-
 from django.db import models
-try:
-    from django.db.transaction import atomic
-except ImportError:
-    from django.db.transaction import commit_on_success as atomic
-from django.db.models.query import QuerySet
-from django.utils.translation import ugettext as _
-from django.core.exceptions import MultipleObjectsReturned, ImproperlyConfigured
 from django.conf import settings
-from odnoklassniki_api import fields
-from odnoklassniki_api.models import OdnoklassnikiManager, OdnoklassnikiModel, OdnoklassnikiPKModel, OdnoklassnikiDeniedAccessError, OdnoklassnikiContentError
-from odnoklassniki_api.decorators import fetch_all
-from datetime import datetime
-from urllib import unquote
+from django.utils.translation import ugettext as _
+from django.core.exceptions import ImproperlyConfigured
+from odnoklassniki_api.models import OdnoklassnikiManager, OdnoklassnikiPKModel
+from odnoklassniki_api.decorators import fetch_all, atomic
 import logging
-import re
-import simplejson as json
 
 log = logging.getLogger('odnoklassniki_group')
 
+if 'odnoklassniki_users' in settings.INSTALLED_APPS:
+    from odnoklassniki_users.models import User
+    from m2m_history.fields import ManyToManyHistoryField
+    users = ManyToManyHistoryField(User)
+else:
+    @property
+    def users(self):
+        raise ImproperlyConfigured("Application 'odnoklassniki_users' not in INSTALLED_APPS")
+
 
 class GroupRemoteManager(OdnoklassnikiManager):
 
@@ -58,6 +57,7 @@ class GroupRemoteManager(OdnoklassnikiManager):
         ids = [m['userId'] for m in response['members']]
         return ids, response
 
+
 class Group(OdnoklassnikiPKModel):
     class Meta:
         verbose_name = _('Odnoklassniki group')
@@ -74,14 +74,16 @@ class Group(OdnoklassnikiPKModel):
 
     members_count = models.PositiveIntegerField()
 
-    photo_id = models.PositiveIntegerField(null=True)
-    picavatar = models.URLField()
+    photo_id = models.BigIntegerField(null=True)
+    pic_avatar = models.URLField()
 
     premium = models.NullBooleanField()
     private = models.NullBooleanField()
     shop_visible_admin = models.NullBooleanField()
     shop_visible_public = models.NullBooleanField()
 
+    users = users
+
     remote = GroupRemoteManager(methods={
         'get': 'getInfo',
         'get_members': 'getMembers',
@@ -90,9 +92,22 @@ class Group(OdnoklassnikiPKModel):
     def __unicode__(self):
         return self.name
 
-#     def remote_link(self):
-#         return 'http://vk.com/club%d' % self.remote_id
-
     @property
     def refresh_kwargs(self):
-        return {'ids': [self.pk]}
\ No newline at end of file
+        return {'ids': [self.pk]}
+
+    def parse(self, response):
+        # avatar
+        if 'picAvatar' in response:
+            response['pic_avatar'] = response.pop('picAvatar')
+        super(Group, self).parse(response)
+
+    @atomic
+    def update_users(self, **kwargs):
+        if 'odnoklassniki_users' not in settings.INSTALLED_APPS:
+            raise ImproperlyConfigured("Application 'odnoklassniki_users' not in INSTALLED_APPS")
+
+        ids = Group.remote.get_members_ids(group=self)
+        self.users = User.remote.fetch(ids=ids)
+
+        return self.users
